==> aws-cdk-scala_2.12-0.6.0-sources.jar: io/burkard/cdk/DefaultStackSynthesizerProps.scala <==
package io.burkard.cdk

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object DefaultStackSynthesizerProps {

  def apply(
    generateBootstrapVersionRule: Option[Boolean] = None,
    imageAssetPublishingExternalId: Option[String] = None,
    qualifier: Option[String] = None,
    imageAssetPublishingRoleArn: Option[String] = None,
    dockerTagPrefix: Option[String] = None,
    fileAssetPublishingRoleArn: Option[String] = None,
    bucketPrefix: Option[String] = None,
    fileAssetPublishingExternalId: Option[String] = None,
    cloudFormationExecutionRole: Option[String] = None,
    deployRoleExternalId: Option[String] = None,
    imageAssetsRepositoryName: Option[String] = None,
    fileAssetsBucketName: Option[String] = None,
    lookupRoleArn: Option[String] = None,
    deployRoleArn: Option[String] = None,
    bootstrapStackVersionSsmParameter: Option[String] = None
  ): software.amazon.awscdk.DefaultStackSynthesizerProps =
    (new software.amazon.awscdk.DefaultStackSynthesizerProps.Builder)
      .generateBootstrapVersionRule(generateBootstrapVersionRule.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .imageAssetPublishingExternalId(imageAssetPublishingExternalId.orNull)
      .qualifier(qualifier.orNull)
      .imageAssetPublishingRoleArn(imageAssetPublishingRoleArn.orNull)
      .dockerTagPrefix(dockerTagPrefix.orNull)
      .fileAssetPublishingRoleArn(fileAssetPublishingRoleArn.orNull)
      .bucketPrefix(bucketPrefix.orNull)
      .fileAssetPublishingExternalId(fileAssetPublishingExternalId.orNull)
      .cloudFormationExecutionRole(cloudFormationExecutionRole.orNull)
      .deployRoleExternalId(deployRoleExternalId.orNull)
      .imageAssetsRepositoryName(imageAssetsRepositoryName.orNull)
      .fileAssetsBucketName(fileAssetsBucketName.orNull)
      .lookupRoleArn(lookupRoleArn.orNull)
      .deployRoleArn(deployRoleArn.orNull)
      .bootstrapStackVersionSsmParameter(bootstrapStackVersionSsmParameter.orNull)
      .build()
}

==> aws-cdk-scala_2.12-0.9.0-sources.jar: io/burkard/cdk/DefaultStackSynthesizerProps.scala <==
package io.burkard.cdk

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object DefaultStackSynthesizerProps {

  def apply(
    generateBootstrapVersionRule: Option[Boolean] = None,
    imageAssetPublishingExternalId: Option[String] = None,
    qualifier: Option[String] = None,
    imageAssetPublishingRoleArn: Option[String] = None,
    dockerTagPrefix: Option[String] = None,
    fileAssetPublishingRoleArn: Option[String] = None,
    bucketPrefix: Option[String] = None,
    fileAssetPublishingExternalId: Option[String] = None,
    cloudFormationExecutionRole: Option[String] = None,
    lookupRoleExternalId: Option[String] = None,
    useLookupRoleForStackOperations: Option[Boolean] = None,
    deployRoleExternalId: Option[String] = None,
    imageAssetsRepositoryName: Option[String] = None,
    fileAssetsBucketName: Option[String] = None,
    lookupRoleArn: Option[String] = None,
    deployRoleArn: Option[String] = None,
    bootstrapStackVersionSsmParameter: Option[String] = None
  ): software.amazon.awscdk.DefaultStackSynthesizerProps =
    (new software.amazon.awscdk.DefaultStackSynthesizerProps.Builder)
      .generateBootstrapVersionRule(generateBootstrapVersionRule.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .imageAssetPublishingExternalId(imageAssetPublishingExternalId.orNull)
      .qualifier(qualifier.orNull)
      .imageAssetPublishingRoleArn(imageAssetPublishingRoleArn.orNull)
      .dockerTagPrefix(dockerTagPrefix.orNull)
      .fileAssetPublishingRoleArn(fileAssetPublishingRoleArn.orNull)
      .bucketPrefix(bucketPrefix.orNull)
      .fileAssetPublishingExternalId(fileAssetPublishingExternalId.orNull)
      .cloudFormationExecutionRole(cloudFormationExecutionRole.orNull)
      .lookupRoleExternalId(lookupRoleExternalId.orNull)
      .useLookupRoleForStackOperations(useLookupRoleForStackOperations.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .deployRoleExternalId(deployRoleExternalId.orNull)
      .imageAssetsRepositoryName(imageAssetsRepositoryName.orNull)
      .fileAssetsBucketName(fileAssetsBucketName.orNull)
      .lookupRoleArn(lookupRoleArn.orNull)
      .deployRoleArn(deployRoleArn.orNull)
      .bootstrapStackVersionSsmParameter(bootstrapStackVersionSsmParameter.orNull)
      .build()
}
